/* This program 
 1) Creates a userinfo Object of Super admin User.
 2) Get all report categories from the report server
User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll
*/

/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>

using System;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using Enums = com.intellica.client.common.Enums;
using Filter = com.intellica.client.common.Filter;
using UserInfo = com.intellica.client.common.UserInfo;
// user info bean 
using HashContainer = com.intellica.client.utils.HashContainer;
// Object used to pass parameters collection
using LayoutManager = com.intellica.client.layout.LayoutManager;
// for report layout management related operations			 
using Category = com.intellica.client.reportutils.Category;
//This class represents the Report Category.
using LayoutHandlerException = com.intellica.client.exception.LayoutHandlerException;
//This Exception class is used for all Layout use cases.
using com.impetus.interaj.globals;

//This class retrieves the list of categories from the Intellicus repository.
public partial class CategoryManager 
{
    public static void GetCategoryList()
	{
		try
		{
			
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
			
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			
			// Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lm = new LayoutManager();
			
			System.Collections.ArrayList vecCatList = System.Collections.ArrayList.Synchronized(new System.Collections.ArrayList(10));
			Filter filterObj = new Filter();
			filterObj.setFilterField(Enums.Filters.CategoryList.OWNERAPPID, requestorUserInfo.UserId);
			filterObj.setFilterField(Enums.Filters.CategoryList.OWNERORGID, requestorUserInfo.Organization);
			
			try
			{
				// This will return vector of category object
				vecCatList = lm.getCategoryList(filterObj, requestorUserInfo);
			}
			catch (LayoutHandlerException e)
			{
				throw new Exception(e.ErrorMessage);
			}
			
			if (vecCatList != null)
			{
				for (int i = 0; i < vecCatList.Count; i++)
				{
					Category category = (Category) vecCatList[i];
                    Logger.debug("Category: " + i);
					Logger.debug("CategoryName: " + category.MenuName);
                    Logger.debug("CategoryId : " + category.CategoryId);
                    Logger.debug("Description: " + category.Description);
                    Logger.debug("IsPublic: " + category.IsPublic);
					Logger.debug("OwnerAppId: " + category.OwnerAppId);
					Logger.debug("OwnerOrgId: " + category.OwnerOrgId);
					Logger.debug("RepositDate: " + category.RepositDate);
					
				}
			}
			else
			{
				Logger.debug("No category exits");
			}
		}
		catch (System.Exception e)
		{
            Logger.error(e);
		}
	}
}