/* This program 
* 1) Creates a userinfo Object of Super admin User.
* 2) Get all report present in the given Category from the report server
*User would require to use following Intellicus jar files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll
*/

/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>

using System;
using System.Collections;
using Filter = com.intellica.client.common.Filter;
using UserInfo = com.intellica.client.common.UserInfo;
// user info bean 
using LayoutHandlerException = com.intellica.client.exception.LayoutHandlerException;
//This Exception class is used for all Layout use cases.
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using LayoutManager = com.intellica.client.layout.LayoutManager;
// for report layout management related operations		
using Category = com.intellica.client.reportutils.Category;
using com.impetus.interaj.globals;

//This class retrieves the list of sub-categories prsent in the given Category from the Intellicus repository.
public partial class CategoryManager
{
    public static void GetSubCategoriesForCategory()
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
			
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			
			// Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lm = new LayoutManager();
			
			//Category Id whose sub categories are to be obtained
            System.String catId = "571937DE-9934-90CB-FFD0-371470A44B7E";
			Category categoryObj = null;
			
			try
			{
				//getting category object corresponding to given category id.
				categoryObj = lm.getCategory(catId, requestorUserInfo);
				
				//now, fill the sub-categories in the category object.
				Filter filter = new Filter();
				filter.setFilterField("ENTITYTYPE", "CATEGORY");
				lm.populateEntityListForCategory(categoryObj, filter, requestorUserInfo);
			}
			catch (LayoutHandlerException lhe)
			{
                Logger.debug("ErrorMessage: " + lhe.Message);
                Logger.debug("RootCause	 : " + lhe.RootCause);
			}
			
			//get the sub-categories LinkedhashMap.
			System.Collections.Specialized.OrderedDictionary subcategories = categoryObj.SubCategories;

            Logger.debug(" Parent Category Name = " + categoryObj.MenuName);

            //iterating through the OrderedDictionary to get the sub-categories
			if (subcategories != null)
			{
                foreach (DictionaryEntry de in subcategories)
                {
                    System.String categoryId = (System.String)de.Key;
                    Category category = (Category)subcategories[categoryId];
                    Logger.debug(" Sub-Category Name = " + category.MenuName);
               }
			}
		}
		catch (System.Exception e)
		{
			Logger.error(e);
		}
	}
}