/*
* This program returns the list of all the DB connections present in the Intellicus Repository.
* User would also require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll
*/

/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>

using System;
using System.Collections;
using com.impetus.interaj.globals;
using DBConnection = com.intellica.client.common.DBConnection;
//This class stores the information regarding a database connection.
using Filter = com.intellica.client.common.Filter;
using UserInfo = com.intellica.client.common.UserInfo;
// user info bean
using LayoutHandlerException = com.intellica.client.exception.LayoutHandlerException;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using LayoutManager = com.intellica.client.layout.LayoutManager;

using EntityAccessRight = com.intellica.client.security.EntityAccessRight;
using EntityInfo = com.intellica.client.security.EntityInfo;
using SecurityManager = com.intellica.client.security.SecurityManager;

//Thrown as and when there is any error in initializing the report Engine interface (REInterface). 
using Enums = com.intellica.client.common.Enums;
// Has Enums for the constants used

// Object used to pass in run report
using AppInfo = com.intellica.client.security.AppInfo;

//For all report layout operations 
//client creates the object of this class.
//The methods of this class are stateless 
//and takes all required information such 
//as requestor User Info etc. in each call.

using ISecurityException = com.intellica.client.exception.ISecurityException;
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;

/// <summary>
/// This class returns the list of all the DB connections present in the Intellicus Repository.
/// </summary>
public partial class DBConnectionMgr
{

    public static void AssignConnectionPrivilegesToRole()
    {
        try
        {
            // Static Init call. it will read the properties for report server related attributes 
            // like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
            //in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
            //with the absolute path of ReportClient.properties.
            ReportClient.init(is_Renamed);

            //Prepare a requestor user info bean object.
            // This user should be present in Intellicus application.
            //Syntax public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
            //@param userId   - : Id of the User Logged-In.
            //@param password - : Password of the User Logged-In.
            //@param orgId    - : Organization Id from which User Logged-In.
            System.String adminuserId = "Admin";
            System.String adminpassword = "Admin";
            System.String organization = "Intellica";
            UserInfo requestorUserInfo = new UserInfo(adminuserId, adminpassword, organization);

            // Create a Security controller class object using its factory 
            // for user management related operations
            //public getInstance method to access the static instance of SecurityManager object
            //Syntax public static SecurityManager Instance
            SecurityManager sMgr = SecurityManager.Instance;

            // UserId of the user whose Category Privileges are to be set			
            System.String roleId = "Manager5";
            System.String OrgId = "Org1";

            // Connection ID whose System Privileges are to be set for the specified user.
            System.String ConnectionName = "DemoReportDB";

            EntityInfo entityInfo = new EntityInfo(ConnectionName, "DBCONNECTION");
            AppInfo appInfo = new AppInfo(roleId, OrgId, "ROLE");

            EntityAccessRight ear = new EntityAccessRight();

            /*public void AppInfo = AppInfo appInfo)Parameters:
            *appInfo - : AppInfo object.
            * */
            ear.AppInfo = appInfo;
            /*	access level can have three values possible.
            *	Deny Access		= 0
            *  Full Access		= 1
            *	Partial Access 	= 2
            *  None Access 	= 3*/
            /**
            * public void AccessLevel = int accessLevel)
            * @param accessLevel : access level can be 0/1/2
            */
            ear.AccessLevel = Enums.SecurityTypes.AccessLevel.FULLACCESS;
            /*public void setAccessRightGrants(String grants)Parameters:
            *grants - : comma separated string specifying grants of access right.*/
            //ear.setAccessRightGrants("0,3");//when Partial rights
            /*public void setOpCode(String opCode)Parameters:
            *opCode - the opCode to set*/
            ear.OpCode = "REPLACE";
            /*public void grantEntityPrivileges(EntityInfo entity,
            EntityAccessRight entityAccessRight,
            UserInfo userInfo)
            throws ISecurityExceptionThis API allows the user to assign access rights information to a user/role/organization or Everyone on an entity. 
			
            *Parameters:
            *entity - The entity object.This object must be created by setting entityId and entityType. entityTypes supported are defined in EntityTypeNames class.
            *entityAccessRight - The entityAccessRight object. This object should contain the AppInfo object with the credentials of the user to which grants are to be assigned and access level as defined in Enums.SecurityTypes.AccessLevel
            *userInfo - The userInfo object for authorization. 
            *Throws: 
            *ISecurityException: - If the request cannot be performed successfully. This happens - 1.if connection can't be established with the engine or 2.if read or write operation cant be performed from or to the engine. 3.If some error has occured while executing the request on the engine. 4.If the response xml obtained from server cannot be parsed 
            *ISecurityException
            * */
            sMgr.grantEntityPrivileges(entityInfo, ear, requestorUserInfo);
        }
        catch (InterfaceInitException iie)
        {
            Logger.error("Could not connect to report server::");
        }
        catch (ISecurityException ise)
        {
            Logger.error("Failed to modify user::" + ise.ExtMessage);
        }
        catch (System.Exception e)
        {
            Logger.error("Error Message:" + e.Message);
        }
    }

}