/*
* This  API is used to delete an existing Database Connection from the Intellicus Repository
* User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll
*/

/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>

using System;
using System.Collections;
//Array list related operations
//This class makes no guarantees as to the order of the map; in particular, 
//it does not guarantee that the order will remain constant over time. 

using com.impetus.interaj.globals;
using DBConnection = com.intellica.client.common.DBConnection;
//This class stores the information regarding a database connection.
using Filter = com.intellica.client.common.Filter;
using UserInfo = com.intellica.client.common.UserInfo;
// user info bean
using LayoutHandlerException = com.intellica.client.exception.LayoutHandlerException;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using LayoutManager = com.intellica.client.layout.LayoutManager;
//For all report layout operations 
//client creates the object of this class.
//The methods of this class are stateless 
//and takes all required information such 
//as requestor User Info etc. in each call.

/// <summary>
/// This class is used to delete an existing Database Connection from the Intellicus Repository
/// </summary>
public partial class DBConnectionMgr 
{
    public static void DeleteConnection()
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
			
			//Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			
			//Connection i.e. to be deleted
			System.String connectionName = "MyConnection";
			
			// Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lmanager = new LayoutManager();
			
			
			System.Collections.Hashtable map = new System.Collections.Hashtable();
			Filter filter = new Filter();
			//For Filter CONNECTION_TYPE=ALL/OLAP ,if nothing is set in the filter only db connections are considered. 
			filter.setFilterField("CONNECTION_TYPE", "ALL");
			
			//Syntax :public java.util.HashMap getDBConnectionList(Filter filter,UserInfo userInfo)
			//Returns the list of DB connections from the Intellicus Repository.
			//It is mandatory to pass filter as a parameter , if olap connection is required to be deleted 
			//As if no filter is passed then,the db connections can be deleted only.
			map = lmanager.getDBConnectionList(filter, requestorUserInfo);

            foreach (DictionaryEntry de in map)
            {
                System.Collections.ArrayList l = (System.Collections.ArrayList)(map[de.Key]);

                //Iterating through the List
                for (int i = 0; i < l.Count; i++)
                {
                    System.Object o = l[i];

                    // ArrayList contains both DBConnection and DBProvider class type
                    // When class type is DBConnection
                    if ("com.intellica.client.common.DBConnection".Equals(System.Convert.ToString(o.GetType().ToString()),StringComparison.CurrentCultureIgnoreCase))
                    {
                        //This class stores the information regarding a database connection 
                        DBConnection dbConn = (DBConnection)l[i];

                        // Check whether the Connection i.e. to be deleted exists or not
                        if (connectionName.Equals(dbConn.ConnectionName))
                        {
                            try
                            {
                                // The method delete given Report Server Connection 
                                // Syntax : public String deleteReportServerConnection(DBConnection dbConnection, UserInfo userInfo)
                                // @ param dbConnection : DBConnection object which needs to be deleted.
                                // @ param userInfo : The UserInfo object  
                                lmanager.deleteReportServerConnection(dbConn, requestorUserInfo);
                            }
                            catch (LayoutHandlerException lhException)
                            {
                                Logger.error(lhException);
                            }
                        } //end inner if
                    } //end Outer if
                } //end for
            }
		}
		catch (System.Exception e)
		{
			Logger.error(e);
		}
	}
}