/*
* This program returns the list of all the DB connections present in the Intellicus Repository.
* User would also require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll
*/

/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>

using System;
using System.Collections;
using com.impetus.interaj.globals;
using DBConnection = com.intellica.client.common.DBConnection;
//This class stores the information regarding a database connection.
using Filter = com.intellica.client.common.Filter;
using UserInfo = com.intellica.client.common.UserInfo;
// user info bean
using LayoutHandlerException = com.intellica.client.exception.LayoutHandlerException;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using LayoutManager = com.intellica.client.layout.LayoutManager;
//For all report layout operations 
//client creates the object of this class.
//The methods of this class are stateless 
//and takes all required information such 
//as requestor User Info etc. in each call.

/// <summary>
/// This class returns the list of all the DB connections present in the Intellicus Repository.
/// </summary>
public partial class DBConnectionMgr 
{
	
    public static void GetConnectionList()
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
			
			//Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			
			//Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lm = new LayoutManager();
			
			System.Collections.Hashtable map = new System.Collections.Hashtable();
			
			Filter filter = new Filter();
			
			//CONNECTION_TYPE =ALL/OLAP is set as filter
			filter.setFilterField("CONNECTION_TYPE", "ALL");
			//Syntax :public java.util.HashMap getDBConnectionList(Filter arg0,UserInfo userInfo)
			//Returns the list of DB connections from the Intellicus Repository.
			map = lm.getDBConnectionList(filter, requestorUserInfo);

            //Iterating through the map
            foreach (DictionaryEntry de in map)
            {
                System.Collections.ArrayList l = (System.Collections.ArrayList)(map[de.Key]);

                //Iterating through the List
                for (int i = 0; i < l.Count; i++)
                {
                    System.Object o = l[i];

                    //ArrayList contains both DBConnection and DBProvider class type
                    //When class type is DBConnection

                    if ("com.intellica.client.common.DBConnection".Equals(System.Convert.ToString(o.GetType().ToString()),StringComparison.CurrentCultureIgnoreCase))
                    {
                        //This class stores the information regarding a database connection 
                        DBConnection dbConn = (DBConnection)l[i];
                        //The following lists the properties of the connection like Connection nam , Connection Type etc...
                        Logger.debug("Connection Name  :  " + dbConn.ConnectionName); //Get the connection name
                        Logger.debug("Connection Type  :  " + dbConn.ConnectionType); //Get the connection type like DB,Olap etc.

                        //getAdminStatus();Retuns valid if connection is valid if connetion is invalid returns invalid
                        Logger.debug("Admin Status  :  " + dbConn.AdminStatus);

                        Logger.debug("Character Set Encoding  :  " + dbConn.CharsetEncoding); //Get Character Set Encoding like utf-8, Not applicable for OLAP connection						

                        Logger.debug("DataCachePurgeFreq  :  " + dbConn.DataCachePurgeFreq); //defines the time when data cached 
                        //for the selected connection should be deleted and refreshed 
                        //, Not applicable for OLAP connection	

                        Logger.debug("IncrementSize  :  " + dbConn.IncrementSize); //specifies the number of connections to open when the all open 
                        //connections are consumed.  For example, if 10 connections are presently opened and 
                        //Incremental Size is 3, then when these 10 connections are consumed, 3 more connections will be opened

                        Logger.debug("InitialConnections  :  " + dbConn.InitialConnections); //Specifies the numkber of initial connection

                        Logger.debug("getMaxConnections  :  " + dbConn.MaxConnections); //Gives the maximum number of possible connections

                        Logger.debug("MetadataCachePurgeFrequency(  :  " + dbConn.MetadataCachePurgeFrequency); //defines the time when metadata 
                        //(table names, field names, etc.) cached 
                        //for the selected connection should be deleted and refreshed
                        //, Not applicable for OLAP connection	

                        Logger.debug("Password  :  " + dbConn.Password); //Gives the password, Not applicable for OLAP connection	
                        Logger.debug("ResubmitIdleTime  :  " + dbConn.ResubmitIdleTime); //Specifies the time after which the connection is submitted after being idle.
                        Logger.debug("StatusMessage  :  " + dbConn.StatusMessage); //Give the connection Status

                        Logger.debug("TimeZone  :  " + dbConn.TimeZone); //Give the Time Zone, Not applicable for OLAP connection	

                        Logger.debug("getUserId  :  " + dbConn.UserId); //Give the user id, Not applicable for OLAP connection	

                        Logger.debug("DbDriver  :  " + dbConn.DbDriver); //Provide the name of the driver.

                        //isBlankCredential() :returns true if password is blank and returns false if Password is provided, Not applicable for OLAP connection	
                        Logger.debug("isBlankCredential  :  " + dbConn.BlankCredential);

                        Logger.debug("isDefault  :  " + dbConn.Default); //Returns true if the connection is a default connection, Not applicable for OLAP connection	

                        Logger.debug("isDefaultOLAP  :  " + dbConn.DefaultOLAP); //returns true if is a default olap connection
                        Logger.debug("isReadOnly  :  " + dbConn.ReadOnly); //returns true if the option readonly is checked, Not applicable for OLAP connection	
                        Logger.debug("isRepository  :  " + dbConn.Repository); ////returns true if  the connection iset as is repository, Not applicable for OLAP connection	
                        Logger.debug("isTestedConnection  :  " + dbConn.isTestedConnection()); //Returns ttrue if the connection is a tested connection
                        Logger.debug("isUseRuntimeCredential  :  " + dbConn.UseRuntimeCredential); //Returns true if the runtime option is checked, Not applicable for OLAP connection	
                        Logger.debug("******************************************************");
                        Logger.debug("");
                        Logger.debug("******************************************************");
                    }
                }
            }
		}
		catch (LayoutHandlerException lhException)
		{
            Logger.error(lhException);
		}
		catch (System.Exception e)
		{
            Logger.error(e);
		}
	}
}