//This program is to create a new category.
//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll

/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>

// This program 
// 1) Create a userinfo Object of current logged in User.
// 2) Get Dashboard widget list for a given category from the report server.

// Import Section
// Use intellica jar to import these classes
using System;
using com.impetus.interaj.globals;
using Enums = com.intellica.client.common.Enums;
using Filter = com.intellica.client.common.Filter;
using UserInfo = com.intellica.client.common.UserInfo;
using DashboardManager = com.intellica.client.dashboard.DashboardManager;
using DashboardWidget = com.intellica.client.dashboard.DashboardWidget;
using DashboardException = com.intellica.client.exception.DashboardException;
using ReportClient = com.intellica.client.init.ReportClient;

//This class is used to get the list of Dashboard widgets present in given Category from the Report Server.
//The user would require to provide the Category ID and its identity i.e UserInfo. 
//The required steps are :  
//1) Create a userInfo Object of the User.
//2) Provide the Category ID whose Dashboard widgets are to be listed
//3) Get the require widget list from the report server
public partial class Dashboard
{
	public static void GetDashboardWidgetsForCategory()
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
			
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			
			// Create a DashboardManager class object 
			// for Dashboard Management related operations			
			DashboardManager dManager = new DashboardManager();
			System.Collections.ArrayList dashBoardWidgetList = new System.Collections.ArrayList();
			
			//Provide the Category Id whose Dashboard list is to be obtained
            System.String categoryId = "571937DE-9934-90CB-FFD0-371470A44B7E";
			
			Filter filterObj = new Filter();
			//To get the Dashboard list
			filterObj.setFilterField(Enums.Filters.EntityList.ENTITYTYPE, Enums.Filters.EntityList.EntityType.DASHBOARD_WIDGET);
			
			//To get Widget list for given Category.
			filterObj.setFilterField(Enums.Filters.EntityList.CATEGORYID, categoryId);
			//Traversal
			filterObj.setFilterField(Enums.Filters.EntityList.TRAVERSAL, Enums.Filters.EntityList.Traversal.DOWN);
			//Getting the Dashboard widget list based on filters sent
			dashBoardWidgetList = dManager.getDashboardWidgetList(filterObj, requestorUserInfo);
			
			//Iterating through the widget list
			System.Collections.IEnumerator itr = dashBoardWidgetList.GetEnumerator();
			System.Console.Out.WriteLine("Widget List in Category - " + categoryId);
			while (itr.MoveNext())
			{
				DashboardWidget dashboardWidget = (DashboardWidget) itr.Current;
                Logger.debug("Dashboard Widget Name = " + dashboardWidget.Name);
                Logger.debug("Dashboard Widget Type = " + dashboardWidget.WidgetType);
                //Logger.debug();
			}
		}
		catch (DashboardException de)
		{
            Logger.error(de);
		}
		catch (System.Exception e)
		{
            Logger.error(e);
		}
	}
}