// This program is to get organization by passing organization Id. 
//The user would require to provide its identity i.e. user Info to get authorized.

//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll

/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>

using System;
using Authentication = com.intellica.client.security.Authentication;
using SecurityManager = com.intellica.client.security.SecurityManager;
//for getting the controller information for all Administration related operations
using UserInfo = com.intellica.client.common.UserInfo;
//For getting user information
using ISecurityException = com.intellica.client.exception.ISecurityException;
//This exception occurs if connection can't be established with the engine 
//or if read or write operation cant be performed from or to the engine
//or If some error has occured while executing the request on the engine.
//or If the response xml obtained from server cannot be parsed 
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using OrgInfo = com.intellica.client.security.OrgInfo;
using com.impetus.interaj.globals;
//Used for getting organisation information>

//This class is to get the organisation by passing the organisation id.
//This class also retrieves information about an existing organisation and 
//several operations can be performed on that organisation.
public partial class Organization
{
    public static void GetOrgById()
	{
		
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
			
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requesterUserInfo = new UserInfo(userId, password, organization);
			
			// Create a SecurityManager class object 
			// for getting the controller information for all Administration related operations
			//public getInstance method to access the static instance of SecurityManager object
			//Syntax public static SecurityManager Instance
			SecurityManager sMgr = SecurityManager.Instance;
			
			//This will get the Information about any existing organisation Organization.	
			//Syntax:public OrgInfo getOrganizationById(String orgId,UserInfo userInfo)
			//                                                          throws ISecurityException
			//@param orgId    : Id of the requested OrgInfo object
			//@param userInfo : The current user details 
			System.String organisationId = "TestOrg";
			OrgInfo orgObj = sMgr.getOrganizationById(organisationId, requesterUserInfo);
			Logger.debug("OrganizationName: " + orgObj.OrgId);
			//This will get the description about the description.
            Logger.debug("OrganizationDescription: " + orgObj.OrgDescription);
			//This will get the mapping type used in the given organization.
			//Syntax public int getMapType()In case the authentication is done 
			//by Host Application this integer value decides what will be the mapping 
			//between users/roles of host application to users/roles of this application.
			//possible values are 1= Application user to Intellica User 
			//                    2=Application user to Intellica Role 
			//                    3=Application role to Intellica User 
			//                    4=Application role to Intellica Role 
            Logger.debug("OrganizationMapType: " + orgObj.MapType);
			//This will get the Authorization mode of the given organization
			//Syntax public int getAuthorizeMode()
			//AuthorizeMode values 
			//1=Intellica 
			//2=LDAP - Reports are deployed on LDAP server 
            Logger.debug("OrganizationAuthorization mode: " + orgObj.AuthorizeMode);
			//This will return the authentication object
			//Syntax public Authentication getAuthenticationObj()sets the Authentication object. 
			//Authentication object keeps the data of tag attributes and data of inner tag . 
			//Its required to get the authentication object to get the authentication mode.
            Logger.debug("OrganizationAuthenticationObject: " + orgObj.AuthenticationObj);
			//An object of authentication class is created.getAuthenticationObj() is called on orgObj that returns
			//an object of authentication class .With the help of the authentication class object get Authentication mode ()
			//method is called that returns the mode of authentication.
			//Syntax public int getAuthenticateMode()Authentication Mode Id values 
			//1= Host Application 
			//2= Intellica
			//3=External Application. 
			//This identifies who will authenticate the users/roles belonging to this organization. 
			Authentication authObj = orgObj.AuthenticationObj;
            Logger.debug("authObj.getAuthenticateMode()=" + authObj.AuthenticateMode);
		}
		catch (ISecurityException ise)
		{
			throw new Exception("Connection cannot be established with the engine or " + "read or write operation cant be performed from or to the engine or" + "some error has occured while executing the request on the engine or" + "If the response xml obtained from server cannot be parsed");
		}
		catch (System.Exception e)
		{
			throw new Exception(e.Message);
		}
	} // End of main function
}