//This  API is used to add a report to an existing Category in the Intellicus repository. 
//This would require User to provide the Category ID, and the details related to the Report
//i.e to be added.
//It would also require User Info to authorize for publish layout rights.

//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll


/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>

using System;
using UserInfo = com.intellica.client.common.UserInfo;
//For getting user information
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error
//in initializing the report Engine interface (REInterface). 
using LayoutHandlerException = com.intellica.client.exception.LayoutHandlerException;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using LayoutManager = com.intellica.client.layout.LayoutManager;
// for report layout management related operations			
using Report = com.intellica.client.reportutils.Report;
using com.impetus.interaj.globals;
//Class contains the details of the irl file. 
// for reading file from the disk.
//For the input/output Exceptions.
//represents an input stream of bytes.


//This class is used to add a report to an existing Category in the Report Server
//The steps followed are :
//1) Create a userinfo Object of current logged in User.
//2) Get the File from the specific location that needs to be added to the Category
//	 and create a report with same contents
//3) Add the so created Report to the existing Category
public partial class ReportLayoutMgr
{
    public static void AddReportLayoutToCategory()
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream in_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(in_Renamed);
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax : public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			
			//Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lm = new LayoutManager();
			
			
			System.String f = "C:\\Documents and Settings\\testfolder\\Desktop\\3.irl";
			System.IO.FileInfo file = new System.IO.FileInfo(f);
			
			//Read the contents from the given file
			System.IO.Stream is_Renamed = new System.IO.FileStream(file.FullName, System.IO.FileMode.Open, System.IO.FileAccess.Read);
			
			// Get the size of the file
			long length = SupportClass.FileLength(file);
			Logger.debug(length);
			// User cannot create an array using a long type.
			// It needs to be an int type.
			// Before converting to an int type, check
			// to ensure that file is not larger than Integer.MAX_VALUE.
			if (length > System.Int32.MaxValue)
			{
				// File is too large
				throw new System.Exception("File is too Large");
			}
			else
			{
				// Create the byte array to hold the data
				byte[] bytes = new byte[(int) length];
				// Read in the bytes
				int offset = 0;
				int numRead = 0;
				while (offset < bytes.Length && (numRead = SupportClass.ReadInput(is_Renamed, bytes, offset, bytes.Length - offset)) >= 0)
				{
					offset += numRead;
				}
				//	Ensure all the bytes have been read in
				if (offset < bytes.Length)
				{
					throw new System.IO.IOException("Could not completely read the file ");
				}
				// Close the input stream and return bytes
				is_Renamed.Close();
				System.String reportName = "Copy3";
                System.String reportID = "Copy3";
				//Pass the Report Menu Name,category Id, and byte[] of IRL File.
				//The constructor to initiate a Report object.
				//Syntax : public Report(String strReportMenuName,String strCategoryId,
				//															byte[] IRLData)
				//@param strReportMenuName - string containing the reports menu name
				//@param strCategoryId - CategoryId of report
				//@param IRLData - byte array of irl data of report
                Logger.debug(System.Text.Encoding.UTF8.GetString(bytes));
				//System.Console.Out.Write(new System.String(SupportClass.ToCharArray(SupportClass.ToByteArray(bytes))));
				//Category ID in which report is to be added
                System.String categoryID = "6D564906-18CE-43FB-930C-DFB2D44792B3";
				
				Report reportToAdd = new Report(reportID, bytes, categoryID);
				
				//Add the Report to the Category with given Category ID
				//This method sets the category Id 
				//Syntax : public void setCategoryId(String strCategoryId)
				//@param strCategoryId - value of the category Id.
				reportToAdd.ReportName = reportName;
				//Uploads a report by taking the Report object as parameter. 
				//This method internally validates the Report object for report paramaters. 
				//The method also verifies if report already exists in the specified category. 
				//In case report object is not validated and verified the method throws LayoutHandlerException exception.
				//The calling code must catch the exception right at the calling place.
				//Syntax : public void uploadReport(Report report, UserInfo userInfo)
				//@param report - Report class instance containing the report layout metadata and the byte array of report layout itself.
				//@param requestorUserInfo - UserInfo object use to validate the user against the application. 
				lm.uploadReport(reportToAdd, requestorUserInfo);
			}
		}
		catch (InterfaceInitException iie)
		{
			Logger.error("Could not connect to report server::" + iie.ErrorMessage);
			//	iie.printStackTrace();
		}
		catch (System.IO.FileNotFoundException fe)
		{
            Logger.error("File Not Found");
		}
		catch (System.IO.IOException ie)
		{
            Logger.error("I/O operations failed or interrupted");
		}
		catch (LayoutHandlerException lhe)
		{
            Logger.error("Unable to upload report");
		}
		catch (System.Exception e)
		{
            Logger.error(e);
		}
	}
}