//This API is used to get the complete list of the Reports in a particular Category 
//from the Intellicus Repository.
//This would require User to provide the Category ID whose reports are to be listed and the
//This would require user to provide UserInfo to authorize for View Reports layout rights.

//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll

/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>

// This program 
// 1) Create a userinfo Object of current logged in User.
// 2) Get Reports list for a given category from the report server 

// Import Section
// Use intellica jar to import these classes
using System;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using UserInfo = com.intellica.client.common.UserInfo;
// Object used to pass in run report
using LayoutManager = com.intellica.client.layout.LayoutManager;
// for report layout management related operations			
using Report = com.intellica.client.reportutils.Report;
//Class contains the details of the irl file. 
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error
//in initializing the report Engine interface (REInterface). 
using LayoutHandlerException = com.intellica.client.exception.LayoutHandlerException;
//This Exception class is used for all Layout use cases.
using com.impetus.interaj.globals;

//This class is used to get the complete list of the Reports in a particular Category from the Report Server.
//The user would require to provide the Category ID and its identity i.e UserInfo. 
//The required steps are :  
//1) Create a userInfo Object of the User.
//2) Provide the Category ID whose Reports are to be listed
//3) Get all reports from the report server
public partial class ReportLayoutMgr  
{
    public static void GetReportListForCategory()
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax : public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			
			//com.intellica.client.layout.LayoutManager class is responsible for managing 
			//all report layout operations. The methods of this class are stateless and 
			//takes all required information such as requestor User Info etc. in each call.		
			LayoutManager lm = new LayoutManager();
			
			//Category ID of the Category whose Reports are required to be Listed 
            System.String catId = "93538096-012F-EC52-9F96-58C8687EDD00";
			
			//Vector that will be used to store the Report List
			System.Collections.ArrayList vecReportList = System.Collections.ArrayList.Synchronized(new System.Collections.ArrayList(10));
			
			try
			{
				// This method returns a vector of Report objects. 
				//The method requests report server and returns the reports present in the 
				//report repository under given report category, both public and private to 
				//requestor user. 
				//The public reports will be restricted to those reports that the requestorUserInfo has access to read. Each report object provides getIsPublic boolean method to identify the scope of report.for the Category of given catId.
				//Syntax : public java.util.Vector getReportListForCategory(String categoryId,
				//													UserInfo requestorUserInfo)
				//@param categoryId - -The category Id of the category from which, the report layout list is requested. Intellicus allows category ids upto 256 charecters long.
				//@param requestorUserInfo - UserInfo for authorization. Pass getEmptyInstance() in case of report server runs in Security-Off mode. 
				vecReportList = lm.getReportListForCategory(catId, requestorUserInfo);
			}
			catch (LayoutHandlerException lhe)
			{
				//If Category does not exist
				Logger.error("Category: " + catId + " does not exist");
			}
			
			// When vector of report list is not empty
			if (vecReportList != null)
			{
				//Iterating through the complete Vector list to get each Report's Details.
				for (int i = 0; i < vecReportList.Count; i++)
				{
					
					// This will return Report Object
					Report report = (Report) vecReportList[i];
					
					//Calling various methods of Report class to get various details.
					System.String reportId = report.ReportId;
					System.String reportName = report.ReportName;
					Logger.debug("ReportName:" + reportName);
					Logger.debug("ReportId:" + reportId);
					Logger.debug("CategoryId:" + report.CategoryId);
					Logger.debug("CategoryMenuName:" + report.CategoryMenuName);
					Logger.debug("DBConnection:" + report.DBConnection);
					Logger.debug("DeploymentRptType:" + report.DeploymentRptType);
					Logger.debug("Description:" + report.Description);
					Logger.debug("DesignMode:" + report.DesignMode);
					Logger.debug("IsPublic:" + report.IsPublic);
					Logger.debug("OwnerAppId:" + report.OwnerAppId);
					Logger.debug("OwnerOrgId:" + report.OwnerOrgId);
					Logger.debug("getPriority:" + report.Priority);
					Logger.debug("getReportAccessRight:" + report.ReportAccessRight);
					Logger.debug("ReportFormat:" + report.ReportFormat);
					Logger.debug("OwnerOrgId:" + report.OwnerOrgId);
					Logger.debug("MenuName:" + report.MenuName);
					Logger.debug("Version:" + report.Version);
					Logger.debug("VersionDate:" + report.VersionDate);
				} //(end for loop)																					
			} //end if 
		}
		catch (InterfaceInitException iie)
		{
			Logger.error("Could not connect to report server::" + iie.ErrorMessage);
			//	iie.printStackTrace();
		}
		catch (System.Exception e)
		{
			Logger.error(e);
		}
	}
}