//This API is used to get the complete list of all the Standard Reports with their SQL from the Intellicus Repository.
//This would require User to provide User Info to authorize for Report layout operations.

//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll

/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>

using System;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using Filter = com.intellica.client.common.Filter;
using InteraConstants = com.intellica.client.common.InteraConstants;
using UserInfo = com.intellica.client.common.UserInfo;
// Object used to pass in run report
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error
//in initializing the report Engine interface (REInterface). 
using LayoutHandlerException = com.intellica.client.exception.LayoutHandlerException;
using LayoutManager = com.intellica.client.layout.LayoutManager;
// for report layout management related operations			
using Report = com.intellica.client.reportutils.Report;
//Class contains the details of the irl file. 
using InteraReportLayout = com.impetus.intera.layout.InteraReportLayout;
using LayoutProviderException = com.impetus.intera.layout.LayoutProviderException;
//A ByteArrayInputStream contains an internal buffer that
using com.impetus.interaj.globals;

//This class is used to get the complete list of all the Standard Reports with its corresponding SQLs from the Report Server.
//The user would require to provide its identity i.e UserInfo. The required steps are :  
//1) Create a userinfo Object of current logged in User.
//2) Get all Standard Reports from the report server using Filter.
//4) Get the IRL Bytes for the standard report and then parse the xml to get SQL Query.
public partial class ReportLayoutMgr 
{
    public static void GetSQLForStandardReport()
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			// when server running in security enabled mode
			//Syntax : public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo userInfo = new UserInfo(userId, password, organization);
			
			//To set the key,value pair for a particular filter field 
			Filter filter = new Filter();
			//Setting Filter to get only Standard/Studio reports
			filter.setFilterField(InteraConstants.SysParams.DSGN_MODE, "STUDIO");
			
			//com.intellica.client.layout.LayoutManager class is responsible for managing 
			//all report layout operations. The methods of this class are stateless and 
			//takes all required information such as requestor User Info etc. in each call.
			LayoutManager lm = new LayoutManager();
			
			//Arraylist that will be used to store the complete list of Reports in Repository.
            System.Collections.ArrayList vecReportList = new System.Collections.ArrayList();
			
			try
			{
				//This method returns a vector of all report names from the report server 
				//The list will be restricted to accessible reports by this user
				//@param userInfo - UserInfo for authorization. 
				vecReportList = lm.getReportList(filter, userInfo);
			}
			catch (LayoutHandlerException lhe)
			{
				Logger.error(lhe);
			}
			//If the Vector contains any element i.e. not equals to null
			if (vecReportList != null)
			{
				//Class is responsible for managing Intellica Report Layout.
				//All report layout parsing requests are first pass on to this class.
				//The class then do the appropriate action to handle that request.
				InteraReportLayout irl = new InteraReportLayout(userInfo);
				System.String sqlQuery = null;
				//Iterating through the complete Vector list to get the Design mode of each Report
				for (int j = 0; j < vecReportList.Count; j++)
				{
					//Type-casting into report Type
					Report report = (Report) vecReportList[j];
					
					//Returns the byte array containing the report layout for the given reportID 
					//from the report layout repository. 
					byte[] reportDetail = lm.getIRLFile(report.ReportId, userInfo);
					
					try
					{
						//Parse the input streamof irl and sets the InteraReportLayout properties. 
						//@param inputStream - : The InputStream instance of the irl data. 
						irl.parse(new System.IO.MemoryStream(reportDetail));
					}
					catch (LayoutProviderException lpe)
					{
                        Logger.error(lpe);
					}
					
					try
					{
						//To get the SQL Query
						sqlQuery = irl.sqlEditor.getSQL();
					}
					catch (System.Exception exc)
					{
                        Logger.error(exc);
					}
					
					Logger.debug("REPORT Name: " + report.MenuName);
					Logger.debug("SQL: " + sqlQuery);
				} //end for
			} //end if
		}
		catch (InterfaceInitException iie)
		{
			Logger.debug("Could not connect to report server::" + iie.ErrorMessage);
			//	iie.printStackTrace();
		}
		catch (System.Exception e)
		{
            Logger.debug(e);
		}
	}
}