//This API is used to get the list of Saved Reports in a particular Category/Report 
//from the Intellicus Repository.
//This would require User to provide the Category ID whose reports are to be listed and the
//This would require user to provide UserInfo to authorize for View Reports layout rights.

//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll

/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>

using System;
//Use intellica jar to import these classes
using Filter = com.intellica.client.common.Filter;
using UserInfo = com.intellica.client.common.UserInfo;
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
using LayoutHandlerException = com.intellica.client.exception.LayoutHandlerException;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using LayoutManager = com.intellica.client.layout.LayoutManager;
// for report layout management related operations			
using SavedReport = com.intellica.client.reportutils.SavedReport;
//For Save Report
using com.impetus.interaj.globals;

//This class is to get the list of saved reports.
public partial class ReportLayoutMgr   
{
    public static void GetSavedReportList()
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
			//		 Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax : public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			//com.intellica.client.layout.LayoutManager class is responsible for managing 
			//all report layout operations. The methods of this class are stateless and 
			//takes all required information such as requestor User Info etc. in each call.		
			LayoutManager lm = new LayoutManager();
			
			//Category ID of the Category whose Reports are required to be Listed 
            System.String catId = "93538096-012F-EC52-9F96-58C8687EDD00"; //category id to be set in filter
            System.String reportId = "A5E2B7D9-AF9C-FE6D-8377-D64AFA3F2938"; //Report Id to be set in filter
			
			//Vector that will be used to store the Report List
			System.Collections.ArrayList vecSavedReportList = System.Collections.ArrayList.Synchronized(new System.Collections.ArrayList(10));
			try
			{
				Filter filter = new Filter();
				filter.setFilterField(com.intellica.client.common.Enums.Filters.SavedReportList.CATID, catId);
				filter.setFilterField(com.intellica.client.common.Enums.Filters.SavedReportList.REPORTID, reportId);
				/**
				* The following method returns arrylist of SavedReport objects.
				* The method requests report server and returns a list of saved reports
				* present in the report repository for the given report ID.
				* The list of saved reports will be restricted to those reports that the
				* requestorUserInfo has access to read.
				* */
				vecSavedReportList = lm.getSavedReportList(filter, requestorUserInfo);
			}
			catch (LayoutHandlerException lhe)
			{
				//If Category does not exist
				Logger.error("Category: " + catId + " does not exist");
			}
			
			// When vector of report list is not empty
			if (vecSavedReportList != null)
			{
				//Iterating through the complete Vector list to get each Report's Details.
				for (int i = 0; i < vecSavedReportList.Count; i++)
				{
					
					SavedReport savedReport = (SavedReport) vecSavedReportList[i];
					Logger.debug("Report Id for the saved report list-" + savedReport.ReportId);
					Logger.debug("Report Name for the saved report list-" + savedReport.RDFName);
				} //(end for loop)																					
			} //end if 
		}
		catch (InterfaceInitException iie)
		{
			Logger.error(iie);
		}
		catch (System.IO.IOException ioe)
		{
            Logger.error(ioe);
		}
	}
}