//This API is used to move an existing report to another Destination Category.
//This would require user to provide requestorUserInfo to authorize for performing Reports related activities.
//User need to provide the ReportID that is to be moved and the Destination Category ID where it is to be moved.

//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll

using System;
using UserInfo = com.intellica.client.common.UserInfo;
//For getting user information
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error
//in initializing the report Engine interface (REInterface). 
using LayoutHandlerException = com.intellica.client.exception.LayoutHandlerException;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using LayoutManager = com.intellica.client.layout.LayoutManager;
// for report layout management related operations			
using Report = com.intellica.client.reportutils.Report;
using com.impetus.interaj.globals;

//Class contains the details of the irl file. 
/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>

/// <summary> 
/// This class is used to move a report to the Category with given Category ID. 
/// </summary>
public partial class ReportLayoutMgr   
{
    public static void MoveReport()
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			// Syntax : public requestorUserInfo(String userId,String password,String orgId)constructor for creating requestorUserInfo instance 
			// @param userId   - : Id of the User Logged-In.
			// @param password - : Password of the User Logged-In.
			// @param orgId    - : Organization Id from which User Logged-In.
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			
			
			// Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lm = new LayoutManager();
			
			// Report class contains the details of the irl file. 
			// This is the default constructor to create report object.
			Report report = new Report();
			
			//ReportID of the Report that is to be moved to new Category						
            System.String reportID = "Copy3";
			
			
			// If want to get name of the Report with given Report ID, use method getReportDetails() to get its details.
			report = lm.getReportDetails(reportID, requestorUserInfo); //To get the Report details of given Report 
			
			// Get the Report name and Set that name in the Report Object for the moved Report
			report.MenuName = report.ReportName; //Assigning same Report Name to  the moved Report
			
			//CategoryID of the Destination Category where the report needs to be moved	
            System.String destCategoryID = "E6F6C28B-5358-A102-E2A2-065F31CCDBE6";
			
			
			//Method to copy the report to anther Category
			//param 1 : sourceReportId - source report id,mandatory argument for moving the report.
			//param 2 : destinationCategoryId - destination category id,where new report has to be moved.if this is null then report objects's category id will be taken as destination category.
			//param 3 : report - instance of Report class for move.
			//param 4 : requestorrequestorUserInfo - requestorUserInfo object for authorization. 
			lm.moveReport(reportID, destCategoryID, report, requestorUserInfo);
		}
		catch (InterfaceInitException iie)
		{
			Logger.error("Could not connect to report server::" + iie.ErrorMessage);
			//	iie.printStackTrace();
		}
		catch (LayoutHandlerException lhe)
		{
			Logger.error("Unable to get the report details or unable to move the report");
		}
		catch (System.Exception e)
		{
			Logger.error(e);
		}
	}
}