//This program is to create a new category.
//User would require to use following Intellicus jar files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll

/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>

using System;
using com.impetus.interaj.globals;
using ReportExecutor = com.intellica.client.report.ReportExecutor;
// Has run report method
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using UserInfo = com.intellica.client.common.UserInfo;
// Object used to pass in run report
using InteraConstants = com.intellica.client.common.InteraConstants;
using HashContainer = com.intellica.client.utils.HashContainer;
// Object used to pass parameters collection
using ClientException = com.intellica.client.exception.ClientException;
// Exception class
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error
//in initializing the report Engine interface (REInterface). 
// For collecting report output in file format
// for writing file to disk

//This class is used to run a report and save it in the desired format.
//Required steps are :
//1) Create a userinfo Object of current logged in User.
//2) Set Report Id for running report. 
//3) Set system parameters needed to run the report.
//4) Set user parameters if required for running report  
//5) Send run request to server and save the report output on the disk in the desired output format.

public partial class ReportOperations
{
	public static void RunReport()
	{
		// Static Init call. it will read the properties for report server related attributes 
		// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
		// in the INTERA_HOME property of the ReportClient.properties file.
		
		try
		{
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
						
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax : public UserInfo(java.lang.String userId,java.lang.String password,java.lang.String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String adminUserId = "Admin";
			System.String adminPassword = "Admin";
			System.String adminOrganization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(adminUserId, adminPassword, adminOrganization);
			
			//Instantiate a collection object for setting system parameters
			HashContainer hcSysParams = new HashContainer();
			
			//fill up the system parameter values
			//Report ID which is required to run
            System.String reportId = "2C01C803-D4F1-5737-FFE3-C16A3A8E3849";
			
			// This will set Id of the report.
			hcSysParams.put("REPORT_ID", reportId); // In database mode only reportId needed.don't prefix category id
			// This will set the output format for the report.report format can be PDF/XLS/HTML
			hcSysParams.put("REPORT_FORMAT", InteraConstants.ReportFormats.PDF);


            // Instantiate a collection object for setting user/business parameters
			HashContainer hcUserParams = new HashContainer();

            ////todo1 fill up the user params if report contains any parameter
			//hcUserParams.put("Country", "Australia"); // Parameter Name as created in the report layout(IRL)	       
			//hcUserParams.put("Role_ID", "3818");
			
			//Instantiate Report Executor, Not Report Runner :-(
			ReportExecutor report = new ReportExecutor();
			
			
			// RUN !! This is the method call for SYNCHRONOUS execution.
			// After the call, you should have your output file in reportdata
			
			// Instantiate stream object
			System.IO.MemoryStream reportData = new System.IO.MemoryStream();
			
			//Executes a report by taking the values of system defined parameters and report 
			//parameters in parameters as HashContainer and gives the generated report data
			//in the passed outputStream.
			//This method generates the complete report, and then returns the control to 
			//the calling code. In this case, the calling code must catch the exceptions 
			//right at the calling place. The calling code can use the output stream after 
			//the method call. 
			report.runReport(requestorUserInfo, hcSysParams, hcUserParams, null, reportData, true);
			
			System.String savedFile = "C:\\SampleReport.pdf";
			//save the byte array to local file. 
			System.IO.FileStream fos = new System.IO.FileStream(savedFile, System.IO.FileMode.Create); // give .pdf for PDF, .xls for XLS 
			reportData.WriteTo(fos);
		}
		catch (InterfaceInitException iie)
		{
            Logger.debug("Could not connect to report server::" + iie.ErrorMessage);
			//	iie.printStackTrace();
		}
		catch (ClientException ce)
		{
            Logger.debug("Error Message:" + ce.ErrorMessage);
		}
		catch (System.IO.FileNotFoundException fnfe)
		{
            Logger.debug("Error Message:" + fnfe.Message);
		}
		catch (System.IO.IOException ioe)
		{
            Logger.debug("Error Message:" + ioe.Message);
		}
		catch (System.Exception e)
		{
            Logger.error(e);
		}
	}
}