/* This program adds column to the Intellicus Repository or removes a column from the Intellicus Repository.
//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll
*/


/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// 
/// This source code is provided without any express or implied warranties whatsoever
/// 
/// 
/// </summary>
using System;
using UserInfo = com.intellica.client.common.UserInfo;
using com.impetus.interaj.globals;
using ReportObjectManager = com.impetus.intera.reportobjects.ReportObjectManager;
//This class is used for Report Object related operations.
using ReportObject = com.impetus.intera.reportobjects.ReportObject;
//This class is super class of all the report objects 
using QueryObject = com.impetus.intera.reportobjects.QueryObject;
// This class contains all the details about the query object.
using QueryObjectColumn = com.impetus.intera.reportobjects.QueryObjectColumn;
//The class contain all the information relate COLUMN Tag of Query Object
using BaseException = com.intellica.client.exception.BaseException;
// This class is the base class of all the application generated exceptions engine may throw.
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error
//in initializing the report Engine interface (REInterface). 
using SQLEditor = com.impetus.intera.layout.sqleditor.SQLEditor;
//This class contains properties and parsing logic for the SQLEDITOR of the report. 
using Enums = com.intellica.client.common.Enums;
// Has Enums for the constants used

/*
* This class is used to add a column to the Intellicus repository or removes a column 
*from the Intellicus Repository. 
*/
public partial class ReportObjectMgr  
{
    public static void AddRemoveColumn()
	{
		// Prepare a requestor user info bean object.
		// This user must have Admin rights to perform user management actions
		// such as create user
		// This user should be present in Intellicus application.
		//Syntax public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
		//@param userId   - : Id of the User Logged-In.
		//@param password - : Password of the User Logged-In.
		//@param orgId    - : Organization Id from which User Logged-In.
		System.String userId = "Admin";
		System.String password = "Admin";
		System.String organization = "Intellica";
		UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
		
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
			System.IO.Stream is_Renamed = new System.IO.BufferedStream(new System.IO.FileStream(@"E:\Intellicus Working\temp\IntellicusDotNetAPI\client\config\ReportClient.properties", System.IO.FileMode.Open, System.IO.FileAccess.Read)); 
			//with the absolute path of ReportClient.properties.
			
			com.intellica.client.init.ReportClient.init(is_Renamed);
			
			//This class contains method to get/replace/add/delete a Query object(QO)
			ReportObjectManager reportObjectManager = new ReportObjectManager();
			
			System.String qoName = "QO";
			
			QueryObject qoObj = (QueryObject) reportObjectManager.getReportObjectByName(Enums.IRO.TYPE.QUERY, qoName, requestorUserInfo);
			
			
			//The class contain all the information relate COLUMN Tag of Query Object 
			//create the coloumn to add			
			QueryObjectColumn qoc = new QueryObjectColumn("BANKS.BANKID", "BankID", "3", "NUMBER");
			//add the column to query object
			qoObj.addColumn(qoc);
			
			//remove the column	
			//removeStatus is true if delete succeeds else false		
			bool removeStatus = qoObj.removeColumn("ID");
			
			//modify the sql to add and remove the columns in it
			SQLEditor sqlEditor = qoObj.SqlEditor;
			//if the complete sql differs from the sql in designed sql
			if (sqlEditor.EditDirty)
			{
				sqlEditor.setSQL("select BANKS.BANKID from BANKS", true);
			}
			else
			{
				//String previousSelectClause = sqlEditor.getClause().getSelect();
				sqlEditor.Clause.Select = "BANKS.BANKID";
				System.String completeSql = sqlEditor.createSQL();
				sqlEditor.setSQL(completeSql, false);
			}
			
			//save the query object in intellicus 
			System.String status = reportObjectManager.replaceReportObject(qoObj.getXML(), requestorUserInfo);
			
			//if the status string contains error 
			if (status.ToLower().IndexOf("error") != - 1)
			{
				Logger.debug("operation status " + status);
				//throw an excpetion if required
			}
		}
		catch (InterfaceInitException iie)
		{
			Logger.debug("Could not connect to report server::" + iie.ErrorMessage);
		}
		catch (BaseException roe)
		{
			Logger.debug("code:" + roe.ErrCode);
			Logger.debug("code:" + roe.ErrorMessage);
		}
		catch (System.Exception e)
		{
			
			Logger.debug("code:" + e.Message);
		}
	}
}