/* This program is used to get a report object by name from the Repository.It also retrieves the attributes of the query object.
//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll
*/


/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>
using System;
using com.impetus.interaj.globals;
using UserInfo = com.intellica.client.common.UserInfo;
using ReportObjectManager = com.impetus.intera.reportobjects.ReportObjectManager;
//This class is used for Report Object related operations.
using QueryObject = com.impetus.intera.reportobjects.QueryObject;
// This class contains all the details about the query object.
using QueryObjectColumn = com.impetus.intera.reportobjects.QueryObjectColumn;
//The class contain all the information relate COLUMN Tag of Query Object
using BaseException = com.intellica.client.exception.BaseException;
// This class is the base class of all the application generated exceptions engine may throw.
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error
//in initializing the report Engine interface (REInterface). 
using Enums = com.intellica.client.common.Enums;
// Has Enums for the constants used

public partial class ReportObjectMgr
{
	
	public static void  GetReportObjectByName()
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			
			com.intellica.client.init.ReportClient.init(is_Renamed);
			
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			
			
			//This class contains method to get/replace/add/delete a Query object(QO)
			ReportObjectManager reportObjectManager = new ReportObjectManager();

            System.String qoName = "QueryObject1";
			
			//To create the Object of Query Object class.
			QueryObject qoObj = (QueryObject) reportObjectManager.getReportObjectByName(Enums.IRO.TYPE.QUERY, qoName, requestorUserInfo);
			
			//To get the number of columns present in the Query Object
			int columnCount = qoObj.ColumnCount;
			//This will display the columns present.
			System.Collections.ArrayList arrColumn = qoObj.ColumnDetails;
			//This will give the connection name.If the connection is set as default connection then no name is displayed
			System.String connectionName = qoObj.ConnectionName;
			//This will give the type of connection
			System.String connectionType = qoObj.ConnectionType;
			//This will give the name of the query object
			System.String qOName = qoObj.Name;
			//This will give the id of the query object
			System.String qOId = qoObj.Id;
			//This will give the type of query object
			System.String qOType = qoObj.Type;
			//This will give the source of query object like SQL or XML.
			System.String qOSrc = qoObj.Source;
			//This will give the class of the query object.The method returns runtime class of the object 
			//UPGRADE_ISSUE: The following fragment of code could not be parsed and was not converted. "ms-help://MS.VSCC.v80/dv_commoner/local/redirect.htm?index='!DefaultContextWindowIndex'&keyword='jlca1156'"
			System.Type obj = qoObj.GetType();
            string qOClass = obj.FullName;
            //Class < ? extends QueryObject > qOClass = qoObj.GetType()
			//This will give the description of the query object if given.Otherwise nothing is displayed.
			System.String desc = qoObj.Description;
			//This will give the fetch data in SQL
			System.String fetchDataSQL = qoObj.FetchDataSQL;
			//This will give the fetch data XML
			System.String fetchDataXML = qoObj.FetchDataXML;
			//This will give the number of filters being applied .
			int filterCount = qoObj.FilterCount;
			//This will return the index of the formula field.Required to specify the the field.
			int formulaFieldIndex = qoObj.getFormulaFieldIndex("SalesAmount");
			
			System.Console.Out.Write("\n");
			System.Console.Out.Write("Query Object Id              " + qOId);
			System.Console.Out.Write("\n");
			System.Console.Out.Write("Query Object Name            " + qOName);
			System.Console.Out.Write("\n");
			System.Console.Out.Write("Query Object Type            " + qOType);
			System.Console.Out.Write("\n");
			System.Console.Out.Write("Source                       " + qOSrc);
			System.Console.Out.Write("\n");
			System.Console.Out.Write("Total Number of Column       " + columnCount);
			System.Console.Out.Write("\n");
			System.Console.Out.Write("Connection Type              " + connectionType);
			System.Console.Out.Write("\n");
			System.Console.Out.Write("Connection Name              " + connectionName);
			System.Console.Out.Write("\n");
			System.Console.Out.Write("Class                        " + qOClass);
			System.Console.Out.Write("\n");
			System.Console.Out.Write("Description                  " + desc);
			System.Console.Out.Write("\n");
			System.Console.Out.Write("FetchDataSQL                 " + fetchDataSQL);
			System.Console.Out.Write("\n");
			System.Console.Out.Write("FetchDataXML                 " + fetchDataXML);
			System.Console.Out.Write("\n");
			System.Console.Out.Write("FilterCount                  " + filterCount);
			System.Console.Out.Write("\n");
			System.Console.Out.Write("Formula Field                " + formulaFieldIndex);
			
			
			System.Console.Out.Write("\n");
			System.Console.Out.Write("The columns present in this query object are: ");
			System.Console.Out.Write("\n");
			System.Console.Out.Write("----------------------------------------------");
			System.Console.Out.Write("\n");
			
			for (int i = 0; i < arrColumn.Count; i++)
			{
				QueryObjectColumn Column = (QueryObjectColumn) arrColumn[i];
				Logger.debug(Column.ColumnName);
				System.Console.Out.Write("\n");
			}
		}
		catch (InterfaceInitException iie)
		{
			Logger.debug("Could not connect to report server::" + iie.ErrorMessage);
		}
		catch (BaseException roe)
		{
			
			Logger.debug("code" + roe.ErrCode);
			Logger.debug("code" + roe.ErrorMessage);
		}
		catch (System.Exception e)
		{
			Logger.debug("code" + e.Message);
		}
	} //End of the main.	
}