/* This API is used to get the list of Report Objects i.e. Query Objects and Parameter Objects.
* This would require user to provide UserInfo to authorize for Reports related Activites.
//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll
*/

//This class returns list of report objects
//The parameter objects and the query objects are displayed as the user desires to view.

/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>
/// 
using System;
using com.impetus.interaj.globals;
using UserInfo = com.intellica.client.common.UserInfo;
using ReportObjectException = com.impetus.intera.reportobjects.ReportObjectException;
//This exception is thrown when unable to handle report objects.
using ReportObjectManager = com.impetus.intera.reportobjects.ReportObjectManager;
//This class is used for Report Object related operations.
using ReportObject = com.impetus.intera.reportobjects.ReportObject;
//This class is super class of all the report objects 
using Enums = com.intellica.client.common.Enums;
// Has Enums for the constants used
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error
//in initializing the report Engine interface (REInterface). 


/*
* This class is used to get either the list of Query Object or Parameter Object.
*/
public partial class ReportObjectMgr  
{
    public static void GetReportObjectList()
	{
		try
		{
			
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			
			com.intellica.client.init.ReportClient.init(is_Renamed);
			
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax : public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			
			//This class contains method to get/replace/add/delete a Query object(QO) or Parameter object(PO)
			ReportObjectManager reportObjectManager = new ReportObjectManager();
			
			// This array stores the list of Report Object		
			System.Collections.ArrayList reportObjList = new System.Collections.ArrayList();
			
			Logger.debug("What report objects you want to have ?");
			Logger.debug("Please Choose 1 for parameter objects :");
			Logger.debug("Please Choose 2 for query objects :");
			
            int choice = 1;
			
			//If User want to get the List of Parameter Object
			if (choice == 1)
			{
				//This class contains all the details about the parameter object, that is, all the details of <PO> tag 
				ReportObject repObjectPrm = ReportObject.createReportObject(Enums.IRO.TYPE.PARAMETER);
				
				//Method used to get the list of Report Object i.e. Parameter Object in this case 
				reportObjList = reportObjectManager.getReportObjectList(repObjectPrm.Type, requestorUserInfo);
			}
			//If User want to get the List of Query Object
			else if (choice == 2)
			{
				//This class contains all the details about the parameter object, that is, all the details of <PO> tag 
				ReportObject repObjectQuery = ReportObject.createReportObject(Enums.IRO.TYPE.QUERY);
				
				//Method used to get the list of Report Object i.e. Query Object in this case 
				reportObjList = reportObjectManager.getReportObjectList(repObjectQuery.Type, requestorUserInfo);
			}
			
			
			// If Arraylist contains some elements
			if (reportObjList != null && !(reportObjList.Count == 0))
			{
				//Iterate the Arraylist 
				for (int i = 0; i < reportObjList.Count; i++)
				{
					ReportObject repObject = (ReportObject) reportObjList[i];
					Logger.debug("");
					
					Logger.debug("report object name: " + repObject.Name);
					Logger.debug("report object type: " + repObject.Type);
				}
			}
			//If Arraylist is empty
			else
			{
				Logger.debug("No report objects exits");
			}
		}
		//end try
		catch (InterfaceInitException iie)
		{
			Logger.debug("Could not connect to report server::" + iie.ErrorMessage);
		}
		catch (ReportObjectException roe)
		{
			Logger.debug("Error Message:" + roe.ExtMessage);
		}
		catch (System.IO.IOException ioe)
		{
			Logger.debug("Error Message:" + ioe.Message);
		}
		catch (System.Exception e)
		{
			Logger.error(e);
		}
	}
}