/* This Sample code retrives the list of report objects for a specific report
* There will be single DataSource/ReportObject/QueryObject for a specific report
//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll
*/

/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>
using System;
using com.impetus.interaj.globals;
using AdhocLayoutException = com.impetus.intera.layout.adhoc.AdhocLayoutException;
using AdhocReportLayout = com.impetus.intera.layout.adhoc.AdhocReportLayout;
//This class holds information about complete Adhoc Report Layout.
//It holds informatiom about DataSource,Template,Filters,Groups,
//Charts,Matrix,Sumarries,Sort-orders used for desiging this Adhoc Report.
using UserInfo = com.intellica.client.common.UserInfo;
// Object used to pass in run report
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error
//in initializing the report Engine interface (REInterface). 
using LayoutHandlerException = com.intellica.client.exception.LayoutHandlerException;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using LayoutManager = com.intellica.client.layout.LayoutManager;
// for report layout management related operations
using Report = com.intellica.client.reportutils.Report;
//Class contains the details of the irl file. 
//A ByteArrayInputStream contains an internal buffer that
//contains bytes that may be read from the stream.

//In this class ,the report id is required to be provided,corresponding to which the
//report objects retrieved from the Intellicus repository 
public partial class ReportObjectMgr 
{
    public static void GetReportObjectforReport()
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			
			com.intellica.client.init.ReportClient.init(is_Renamed);
			
			//Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			
			//Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lm = new LayoutManager();
			Report report = new Report();
			//Report id provided whose report objects is required to be retrieved 
            System.String reportId = "TestAdhocReport1"; //System generated report id
			report.ReportId = reportId;
			
			//This method returns the menu Name
			//Syntax :public String getMenuName() 
			Logger.debug("report=" + report.MenuName);
			
			//This method Returns the byte array containing the report layout for the 
			//given reportID from the report layout repository.
			//public byte[] getIRLFile(String reportId,UserInfo userInfo)
			//@param : reportId - The report id of the requested report layout.
			//@param : userInfo - UserInfo object use to validate the user against the application. 
			byte[] reportIRL = lm.getIRLFile(report.ReportId, requestorUserInfo);
			
			//New object of AdhocReportLayout is created
			AdhocReportLayout adhocReportLayout = new AdhocReportLayout();
			
			//This method is used for parsing of Nodes.This method can be
			//used to parse individual report object.
			adhocReportLayout.parseXml(new System.IO.MemoryStream(reportIRL));
			
			//Data Source means Report Object used or Query Object used.
			Logger.debug("REPORT: " + report.MenuName+ ", DATA SOURCE: " + adhocReportLayout.getDataSource().Name + ", TYPE: " + adhocReportLayout.getDataSource().Type);
		}
		catch (InterfaceInitException iie)
		{
			Logger.debug("Could not connect to report server::" + iie.ErrorMessage);
		}
		catch (LayoutHandlerException lhe)
		{
			Logger.debug("Error Message:" + lhe.ErrorMessage);
		}
		catch (AdhocLayoutException ale)
		{
			Logger.debug("Error Message:" + ale.ErrorMessage);
		}
		catch (System.Exception e)
		{
			Logger.error(e);
		}
	}
}