/* This Sample code retrives the list of report objects for the reports of a specific category.
//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll
*/


/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>
using System;
using com.impetus.interaj.globals;
using AdhocLayoutException = com.impetus.intera.layout.adhoc.AdhocLayoutException;
using AdhocReportLayout = com.impetus.intera.layout.adhoc.AdhocReportLayout;
//This class holds information about complete Adhoc Report Layout.
//It holds informatiom about DataSource,Template,Filters,Groups,
//Charts,Matrix,Sumarries,Sort-orders used for desiging this Adhoc Report.
using UserInfo = com.intellica.client.common.UserInfo;
// Object used to pass in run report
using LayoutHandlerException = com.intellica.client.exception.LayoutHandlerException;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using LayoutManager = com.intellica.client.layout.LayoutManager;
// for report layout management related operations
using Report = com.intellica.client.reportutils.Report;
//Class contains the details of the irl file. 
//A ByteArrayInputStream contains an internal buffer that
//contains bytes that may be read from the stream.
//Implements all optional list operations, and permits all elements, including null.
//In addition to implementing the List interface, this class provides methods to 
//manipulate the size of the array that is used internally to store the list.
//For operation using list
//The Vector class implements a growable array of objects. 
//Like an array, it contains components that can be accessed 
//using an integer index. However, the size of a Vector can grow 
//or shrink as needed to accommodate adding and removing items after 
//the Vector has been created.
//In this class category Id is required to be provided ,corresponding to which the reports are retrieved 
// and corresponding to each report,list of report objects are retrieved.
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error
// in initializing the report Engine interface (REInterface). 

public partial class ReportObjectMgr  
{
    public static void GetReportObjectsForCategory()
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			
			com.intellica.client.init.ReportClient.init(is_Renamed);
			
			//Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as create user
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			
			//Create a Layout Manager class object 
			// for report layout management related operations			
			LayoutManager lm = new LayoutManager();
			System.Collections.ArrayList vecReportList = System.Collections.ArrayList.Synchronized(new System.Collections.ArrayList(10));


            System.String catId = "F5DD41BC-5194-494A-5BD3-1B3127FDD520"; //System generated category id.
			
			//The method requests report server and returns the reports present in the Category 
			//repository under given report category, both public and private to requestor user. 
			//The public reports will be restricted to those reports that the requestorUserInfo has 
			//access to read. 
			// This will return Vector of report objects for the catId.
			//Syntax : public java.util.Vector getReportListForCategory(String categoryId,UserInfo requestorUserInfo)
			//@param : categoryId -The category Id of the category from which, the report layout list is requested. 
			//         Intellicus allows category ids upto 256 charecters long.
			//@param : requestorUserInfo - UserInfo for authorization. 
			vecReportList = lm.getReportListForCategory(catId, requestorUserInfo);
			
			// When vector of report list is not empty
			if (vecReportList != null)
			{
				System.Collections.IList reportObjectList = new System.Collections.ArrayList();
				for (int i = 0; i < vecReportList.Count; i++)
				{
					
					// This will return the Report Object
					Report report = (Report) vecReportList[i];
					
					Logger.debug("report=" + report.MenuName);
					//This method Returns the byte array containing the report layout for the 
					//given reportID from the report layout repository.
					//public byte[] getIRLFile(String reportId,UserInfo userInfo)
					//@param : reportId - The report id of the requested report layout.
					//@param : userInfo - UserInfo object use to validate the user against the application. 
					byte[] reportIRL = lm.getIRLFile(report.ReportId, requestorUserInfo);
					
					AdhocReportLayout adhocReportLayout = new AdhocReportLayout();
					//This method is used for parsing of Nodes.This method can be
					//used to parse individual report object.
					adhocReportLayout.parseXml(new System.IO.MemoryStream(reportIRL));
					//For each report the report objects are retrieved from the Intellicus repository
					//Data Source means Report object used or Query object used.
					Logger.debug("REPORT: " + report.MenuName + ", DATA SOURCE: " + adhocReportLayout.getDataSource().Name + ", TYPE: " + adhocReportLayout.getDataSource().Type);
					
					//If the report object list already contains the report object,it will not add report object to it.
					//That means duplicate report objects will not be added to list.
					if (!reportObjectList.Contains(adhocReportLayout.getDataSource().Name))
					{
						reportObjectList.Add(adhocReportLayout.getDataSource().Name);
					}
				}
				Logger.debug("ReportObject List for category:");
				for (int j = 0; j < reportObjectList.Count; j++)
				{
					Logger.debug(reportObjectList[j]);
				}
			}
		}
		catch (InterfaceInitException iie)
		{
			Logger.debug("Could not connect to report server::" + iie.ErrorMessage);
		}
		catch (LayoutHandlerException lhe)
		{
			Logger.debug("ErrorMessage:" + lhe.ExtMessage);
		}
		catch (AdhocLayoutException ale)
		{
			Logger.debug("ErrorMessage:" + ale.ExtMessage);
		}
		catch (System.Exception e)
		{
			Logger.error(e);
		}
	}
}