/* This sample code is to replace existing query object in the Intellicus repository.
* This would require user to provide UserInfo to authorize for ReportObjects related Activities.
//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll
*/

/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>
using System;
using com.impetus.interaj.globals;
using UserInfo = com.intellica.client.common.UserInfo;
using QueryObjectColumn = com.impetus.intera.reportobjects.QueryObjectColumn;
//This is for setting query object column details.
using ReportObjectException = com.impetus.intera.reportobjects.ReportObjectException;
using ReportObjectManager = com.impetus.intera.reportobjects.ReportObjectManager;
//This class is used for Report Object related operations.
using QueryObject = com.impetus.intera.reportobjects.QueryObject;
// This class contains all the details about the query object.
using SQLEditor = com.impetus.intera.layout.sqleditor.SQLEditor;
//This class contains properties and parsing logic for the SQLEDITOR of the report. 
using Enums = com.intellica.client.common.Enums;
// Has Enums for the constants used
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error
// in initializing the report Engine interface (REInterface). 

public partial class ReportObjectMgr 
{
    public static void ReplaceQueryObject()
	{
		
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			
			com.intellica.client.init.ReportClient.init(is_Renamed);
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax : public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			
			
			//This is manager class and contains method to get/replace/add/delete a Query object(QO)
			ReportObjectManager reportObjectManager = new ReportObjectManager();
			
			//Query Object with given name, this should exist in the intellicus Repository   	 
            System.String qOName = "QueryObject1";
			
			//This is to Get java object of query object.
			//getReportObjectByName method returns report object type object and you would require
			// to type cast this object with java objet of Query Object class.
			QueryObject qObject = (QueryObject) reportObjectManager.getReportObjectByName(Enums.IRO.TYPE.QUERY, qOName, requestorUserInfo);
			
			
			//For Adding a new Column
			
			//create the coloumn to be added and set its attributes.
			//public QueryObjectColumn(String columnName,String caption,String width, String dataType)			
            QueryObjectColumn qocAdd = new QueryObjectColumn("ORDERS.ORDER_DT", "Order Date", "30", "CHAR");
			//Setting other Attributes for the above Column
			//To Set the Alignment for the Column
			// Left Alignment: 0 , Right Alignment: 1
			qocAdd.Alignment = 1;
			//To set the Data Type CHAR/NUMBER/DATE
			qocAdd.DataType = "CHAR";
			//Whether to hide this column or not,
			// True : For hidding the Column
			// False: For not hiding.
			// Default value if False.
			qocAdd.Hidden = false;
			//To set the width
			qocAdd.Width = "30";
			//To set this column in a group
			qocAdd.GroupLabelCaption = "Order Date 1";
			//To set the Output Format
			qocAdd.Format = "CHAR";
			System.String hyperLink = "http://www.google.com";
			qocAdd.Hyperlink = hyperLink;
			
			//add this column in the query object
			qObject.addColumn(qocAdd);
			
			
			//For Removing an Existing Column from the query object.
            bool removeStatus = qObject.removeColumn("ORDER_DT");
			Logger.debug("Column Removed   :   " + removeStatus);
			
			
			//For modifying Attributes of existing Columns
			// This is to change width and other attributes of column Salary in the query object
            System.String captionName = "Cust No";
			
			//This will return array list of all the columns in the query object along with the column details.
			System.Collections.ArrayList list = qObject.ColumnDetails;
			
			//This will iterate all the columns and will change attributes for column Salary.
			for (int i = 0; i < list.Count; i++)
			{
				QueryObjectColumn qoc = (QueryObjectColumn) list[i];
				if (captionName.Equals(qoc.Caption))
				{
					qoc.Width = "40";
					qoc.DataType = "CHAR";
					qoc.Hidden = true;
				}
			}
			
			//This will set all the changes made in the column of the query object.
			qObject.ColumnDetails = list;
			
			//For modifying Query statements.
			//This is to get Object of SQLEditor class fron the query object.
            SQLEditor sqlEditor = qObject.SqlEditor;
			
			//Set the new query statement to replace existing Query.
            System.String ReplaceSql = "select ORDERS.ORDER_DT from ORDERS";
			sqlEditor.setSQL(ReplaceSql, true);
			
			//This will send request to intellicus for replacing report object with the changes made.
			//public void replaceReportObject(ReportObject reportObject,UserInfo userInfo)
			reportObjectManager.replaceReportObject(qObject, requestorUserInfo);
			
			Logger.debug("Query object is replaced");
		}
		//end try
		catch (InterfaceInitException iie)
		{
			Logger.debug("Could not connect to report server::" + iie.ErrorMessage);
			//	iie.printStackTrace();
		}
		catch (ReportObjectException roe)
		{
			Logger.debug("Error Message:" + roe.ExtMessage);
		}
		catch (System.Exception e)
		{
			Logger.error(e);
		}
	}
}