//This API is used to save the Report Obeject i.e. Parameter Object or Query Object in the Intellicus Repository
//This would require user to provide UserInfo to authorize for Reports related Activites.

//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll


//This class saves the report objects: parameter objects and the query objects
/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>
using System;
using com.impetus.interaj.globals;
using UserInfo = com.intellica.client.common.UserInfo;
using QueryObjectColumn = com.impetus.intera.reportobjects.QueryObjectColumn;
using ReportObjectException = com.impetus.intera.reportobjects.ReportObjectException;
using ReportObjectManager = com.impetus.intera.reportobjects.ReportObjectManager;
//This class is used for Report Object related operations.
using ReportObject = com.impetus.intera.reportobjects.ReportObject;
//This class is super class of all the report objects 
using QueryObject = com.impetus.intera.reportobjects.QueryObject;
// This class contains all the details about the query object.
using SQLEditor = com.impetus.intera.layout.sqleditor.SQLEditor;
//This class contains properties and parsing logic for the SQLEDITOR of the report. 
using Enums = com.intellica.client.common.Enums;
// Has Enums for the constants used
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error
//in initializing the report Engine interface (REInterface). 

/*
* This class is used to create a Report Object and save it in the Intellicus Repository
*/
public partial class ReportObjectMgr  
{
    public static void SaveReportObject()
	{
		
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			
			com.intellica.client.init.ReportClient.init(is_Renamed);
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax : public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			
			
			//This class contains method to get/replace/add/delete a Query object(QO)
			//It is also used for Report Object related operations. It acts as the manager for all the classes in this package. 
			ReportObjectManager reportObjectManager = new ReportObjectManager();
			
			
			Logger.debug("What report objects you want to Save?");
			Logger.debug("Choose 1 for parameter objects :");
			Logger.debug("Choose 2 for query objects :");
			
            int choice = 1;

			//If User want to save the Parameter Object            
			if (choice == 1)
			{
				ReportObject repObjectPrm = ReportObject.createReportObject(Enums.IRO.TYPE.PARAMETER);
				//reportObjList=reportObjectManager.getReportObjectList(repObjectPrm.getType(),userInfo);	
				
				System.String prmObject = "newPrmObject1";
				repObjectPrm.Name = prmObject;
				
				//Method used to save the Report Object in the Repository
                reportObjectManager.addReportObject(repObjectPrm, requestorUserInfo);
			}
			//If User want to save the Query Object       
			else if (choice == 2)
			{
				QueryObject repObjectQuery = (QueryObject) ReportObject.createReportObject(Enums.IRO.TYPE.QUERY);
				// reportObjList=reportObjectManager.getReportObjectList(repObjectQuery.getType(),userInfo); 
				
				System.String qOName = "newQObject1";
				repObjectQuery.Name = qOName;
				
				repObjectQuery.ConnectionType = "Default";
				// If Connection Type is Named then To set the Connection name for the Querry Object.
				// qoObj.setConnectionName("Oracle");
				// Create the SQLEditor Object.
				SQLEditor sqlEditor = repObjectQuery.SqlEditor;
				// To set the SQL for fields in Query Object.
				sqlEditor.setSQL("Select * from Orders", true);
				// To add the columns in Query Object.
				// QueryObjectColumn(String columnName,
				//                   String caption,
				//                   String width,
				//                   String dataType)
				QueryObjectColumn qoc1 = new QueryObjectColumn("JOB", "JOB", "10", "");
				QueryObjectColumn qoc2 = new QueryObjectColumn("ENAME", "EMPLOYEE NAME", "10", "");
				QueryObjectColumn qoc3 = new QueryObjectColumn("SAL", "SALARY", "10", "");
				// To make an Array of the columns.
				System.Collections.ArrayList ArrColumn = new System.Collections.ArrayList();
				ArrColumn.Add(qoc1);
				ArrColumn.Add(qoc2);
				ArrColumn.Add(qoc3);
				// To set the columns in the Query Object.
				repObjectQuery.ColumnDetails = ArrColumn;
				
				// This will save the query objects	 
                reportObjectManager.addReportObject(repObjectQuery, requestorUserInfo);
			}
		}
		//end try
		catch (InterfaceInitException iie)
		{
			Logger.debug("Could not connect to report server::" + iie.ErrorMessage);
		}
		catch (ReportObjectException roe)
		{
			Logger.debug("Error Message:" + roe.ExtMessage);
		}
		catch (System.IO.IOException ioe)
		{
			Logger.debug("Error Message:" + ioe.Message);
		}
		catch (System.Exception e)
		{
			Logger.error(e);
		}
	}
}