//This API is used to assign the Access privileges of a Category to the existing Role. 
//User need to provide 
//						- RoleID to which the access rights are to be provided
//						- Category ID of the Category for which the access rights are to be provided
//						- Access Rights that are to be provided to the role. 
//This would also require user to provide UserInfo to authorize for Roles related Activities.

//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll


/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>
using System;
using com.impetus.interaj.globals;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using UserInfo = com.intellica.client.common.UserInfo;
// Object used to pass in run report
using AppInfo = com.intellica.client.security.AppInfo;
using EntityAccessRight = com.intellica.client.security.EntityAccessRight;
using EntityInfo = com.intellica.client.security.EntityInfo;
using SecurityManager = com.intellica.client.security.SecurityManager;
//Controller class for all security related operations
using ISecurityException = com.intellica.client.exception.ISecurityException;
// Exception class for all security related operations.
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
using Enums = com.intellica.client.common.Enums;
// Has Enums for the constants used

/* This class 
* 1)Will get Role Info object for the specified role Id
* 2)Will Assign category privileges to the specified role for the specified Category
*/
public partial class RoleManagement 
{
	
    public static void AssignCategoryPrivilegesToRole()
	{
		
		try
		{
			
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
			
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as Add role etc.
			//Syntax public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String userId = "Admin";
			System.String password = "Admin";
			System.String organization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(userId, password, organization);
			
			
			// Create a Security controller class object using its factory 
			// for user/role management related operations
			SecurityManager sMgr = SecurityManager.Instance;
			
			//RoleID of the Role for which access rights are to be assigned			
			System.String roleId = "Manager5"; //role Id to be checked whether exists or not in the Intellicus server
			System.String orgId = "Org1";
            System.String categoryId = "6D564906-18CE-43FB-930C-DFB2D44792B3"; // Id of the category to be assigned to the Role
			
			EntityInfo entityInfo = new EntityInfo(categoryId, "CATEGORY");
			AppInfo appInfo = new AppInfo(roleId, orgId, "ROLE");
			
			EntityAccessRight ear = new EntityAccessRight();
			
			/*public void AppInfo = AppInfo appInfo)Parameters:
			*appInfo - : AppInfo object.
			* */
			ear.AppInfo = appInfo;
			/*	access level can have three values possible.
			*	Deny Access		= 0
			*  Full Access		= 1
			*	Partial Access 	= 2
			*  None Access 	= 3*/
			/**
			* public void AccessLevel = int accessLevel)
			* @param accessLevel : access level can be 0/1/2
			*/
			ear.AccessLevel = Enums.SecurityTypes.AccessLevel.FULLACCESS;
			/*public void setAccessRightGrants(String grants)Parameters:
			*grants - : comma separated string specifying grants of access right.*/
			//ear.setAccessRightGrants("0,3");//When partial rights
			/*public void setOpCode(String opCode)Parameters:
			*opCode - the opCode to set*/
			ear.OpCode = "REPLACE";
			/*public void grantEntityPrivileges(EntityInfo entity,
			EntityAccessRight entityAccessRight,
			UserInfo userInfo)
			throws ISecurityExceptionThis API allows the user to assign access rights information to a user/role/organization or Everyone on an entity. 
			
			*Parameters:
			*entity - The entity object.This object must be created by setting entityId and entityType. entityTypes supported are defined in EntityTypeNames class.
			*entityAccessRight - The entityAccessRight object. This object should contain the AppInfo object with the credentials of the user to which grants are to be assigned and access level as defined in Enums.SecurityTypes.AccessLevel
			*userInfo - The userInfo object for authorization. 
			*Throws: 
			*ISecurityException: - If the request cannot be performed successfully. This happens - 1.if connection can't be established with the engine or 2.if read or write operation cant be performed from or to the engine. 3.If some error has occured while executing the request on the engine. 4.If the response xml obtained from server cannot be parsed 
			*ISecurityException
			* */
			sMgr.grantEntityPrivileges(entityInfo, ear, requestorUserInfo);
		}
		catch (InterfaceInitException iie)
		{
            Logger.error("Could not connect to report server::" + iie.ErrorMessage);
		}
		catch (ISecurityException e)
		{
			// Rootcause message sent by the report server 
			// for Assigning category privileges to the specified role 
			Logger.error(e);
		}
		catch (System.Exception e)
		{
            Logger.error(e);
		}
	} // End of main function
}