//This API is used to assign the Access privileges for a Report to the Role. 
//The user would require to provide its identity i.e. user Info as well as the Role Info 
//and the Report for which the access rights are to be given.

//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll


/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>
using System;
using com.impetus.interaj.globals;
using Enums = com.intellica.client.common.Enums;
using UserInfo = com.intellica.client.common.UserInfo;
using ReportPrivileges = com.intellica.client.common.Enums.SecurityTypes.ReportPrivileges;
//This class has the enums for Report Privileges
using ISecurityException = com.intellica.client.exception.ISecurityException;
//This Exception class is used for all 
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Security related use cases
using ReportClient = com.intellica.client.init.ReportClient;
//Has init method
using AppInfo = com.intellica.client.security.AppInfo;
using EntityAccessRight = com.intellica.client.security.EntityAccessRight;
using EntityInfo = com.intellica.client.security.EntityInfo;
using RoleInfo = com.intellica.client.security.RoleInfo;
//Stores the information about a role in the application.
using SecurityManager = com.intellica.client.security.SecurityManager;
//This is the controller class for all operations 
//related to Security.These operations are conducted 
//by Administrator or the SuperAdministrator

//This class provides access rights of a particular report to the specified Role
//The user require to provide the Role Info , Report ID , Category ID and the 
//details of the user who is providing the access rights.
public partial class RoleManagement  
{
    public static void AssignReportPrivilegesToRole()
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
			
			// Prepare a Admin user info bean object.
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			
			System.String adminId = "Admin";
			System.String adminPassword = "Admin";
			System.String adminOrganization = "Intellica";
			
			UserInfo adminUserInfo = new UserInfo(adminId, adminPassword, adminOrganization);
			
			
			//	Create a Security Manager class object using its factory 
			// for user management related operations
			//public getInstance method to access the static instance of SecurityManager object
			//Syntax public static SecurityManager Instance
			SecurityManager sMgr = SecurityManager.Instance;
			
			
			//Role Info for which Report Privileges are to be set
			//public RoleInfo(String strRoleId, String orgId)
			//@param strRoleId -  Id of the Role
			//@param orgId -  Id of the Organization the Role belongs
			System.String roleId = "Manager5";
			System.String organisationId = "Org1";
            System.String reportId = "EC3EFF3C-F4F3-F526-107A-FA5D50586867";
			
			EntityInfo entityInfo = new EntityInfo(reportId, "REPORT");
			AppInfo appInfo = new AppInfo(roleId, organisationId, "ROLE");
			
			EntityAccessRight ear = new EntityAccessRight();
			
			/*public void AppInfo = AppInfo appInfo)Parameters:
			*appInfo - : AppInfo object.
			* */
			ear.AppInfo = appInfo;
			/*	access level can have three values possible.
			*	Deny Access		= 0
			*  Full Access		= 1
			*	Partial Access 	= 2
			*  None Access 	= 3*/
			/**
			* public void AccessLevel = int accessLevel)
			* @param accessLevel : access level can be 0/1/2
			*/
			ear.AccessLevel = Enums.SecurityTypes.AccessLevel.FULLACCESS;
			/*public void setAccessRightGrants(String grants)Parameters:
			*grants - : comma separated string specifying grants of access right.*/
			//ear.setAccessRightGrants("0,3");//When partial rights
			/*public void setOpCode(String opCode)Parameters:
			*opCode - the opCode to set*/
			ear.OpCode = "REPLACE";
			/*public void grantEntityPrivileges(EntityInfo entity,
			EntityAccessRight entityAccessRight,
			UserInfo userInfo)
			throws ISecurityExceptionThis API allows the user to assign access rights information to a user/role/organization or Everyone on an entity. 
			
			*Parameters:
			*entity - The entity object.This object must be created by setting entityId and entityType. entityTypes supported are defined in EntityTypeNames class.
			*entityAccessRight - The entityAccessRight object. This object should contain the AppInfo object with the credentials of the user to which grants are to be assigned and access level as defined in Enums.SecurityTypes.AccessLevel
			*userInfo - The userInfo object for authorization. 
			*Throws: 
			*ISecurityException: - If the request cannot be performed successfully. This happens - 1.if connection can't be established with the engine or 2.if read or write operation cant be performed from or to the engine. 3.If some error has occured while executing the request on the engine. 4.If the response xml obtained from server cannot be parsed 
			*ISecurityException
			* */
			sMgr.grantEntityPrivileges(entityInfo, ear, adminUserInfo);
		}
		catch (InterfaceInitException iie)
		{
            Logger.error("Could not connect to report server::" + iie.ErrorMessage);
			//	iie.printStackTrace();
		}
		catch (ISecurityException ise)
		{
            Logger.error("Error Message:" + ise.ExtMessage);
		}
		catch (System.Exception e)
		{
			Logger.error(e);
		}
	}
}