/*This  API is used to check whether the Report Server is running on the specified IP and Port or not.
//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll
*/

/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>
using System;
using com.impetus.interaj.globals;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using ErrorMap = com.intellica.client.exception.ErrorMap;
//defines enums for different messages.
using SecurityManager = com.intellica.client.security.SecurityManager;
// Has user management methods
using ISecurityException = com.intellica.client.exception.ISecurityException;
// Thrown as and when connecttion fails to report server or when user management fails
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error in initializing the report Engine interface (REInterface). 

/*
* This class
* 1) Initializes report client first,
* 2) checks if report server running on the specified IP and Port
*/
public class ServerConnectivity
{
    public static void TestServerConnectivity()
	{
		try
		{
			
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
		}
		catch (InterfaceInitException iie)
		{
            Logger.error(iie);
		}
		catch (System.IO.IOException ioe)
		{
			Logger.error(ioe);
		}
		
		
		try
		{
			
			// Create a Security controller class object using its factory 
			// for user management related operations
			SecurityManager sMgr = SecurityManager.Instance;
			
			
			bool securityMode = false;
			
			//If it gives Exception, then failed to connect Report Server .
			securityMode = sMgr.SecurityMode;
		}
		catch (ISecurityException ise)
		{
			if (ise.ErrCode == ErrorMap.E_NS_CONNECTIONG_TO_SERVER)
			{
                Logger.error("Failed to Connect to report server");
			}
		}
	}
}