// This program is to Assign a specified role to the application user 
//The requestor user would require to provide its identity i.e. user Info to get authorize for providing role
//rights to the particular user

//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll


/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>
using System;
using com.impetus.interaj.globals;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using UserInfo = com.intellica.client.common.UserInfo;
// Object used to pass in run report
using SecurityManager = com.intellica.client.security.SecurityManager;
//Controller class for all security related operations  
using RoleInfo = com.intellica.client.security.RoleInfo;
// Has information about a role in the application
using ISecurityException = com.intellica.client.exception.ISecurityException;
// Exception class for all security related operations.
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error
// in initializing the report Engine interface (REInterface). 

//This class assigns a role to the application user.
public partial class UserManagement   
{
    public static void AssignRoleToUser()
	{
		
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
			
			
			// Prepare a requestor user info bean object.
			// This user must have Admin rights to perform user management actions
			// such as Add role etc.
			//Syntax public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String adminUserId = "Admin";
			System.String adminPassword = "Admin";
			System.String adminOrganization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(adminUserId, adminPassword, adminOrganization);
			
			
			System.String roleId = "Manager"; // Id of the role to be Assigned
			System.String userId = "MNormal1"; // Id of the application user
			System.String orgId = "Org1"; //Id of the organization to which the application user belongs
			// Create a Security controller class object using its factory 
			// for user/role management related operations
			//public getInstance method to access the static instance of SecurityManager object
			//Syntax public static SecurityManager Instance
			SecurityManager sMgr = SecurityManager.Instance;
			
			// This will return RoleInfo for the specified roleId if exists or 
			// will throw exception if role with this roleId does not exists
			// public RoleInfo getRoleById(String roleId,String orgId,
			//                            UserInfo userInfo)throws ISecurityException
			
			//@param roleId - : Id of the requested RoleInfo object
			//@param orgId - : Organization Id of the requested role
			//@param userInfo - : The current user details 
			RoleInfo roleInfo = sMgr.getRoleById(roleId, orgId, requestorUserInfo);
			
			
			// This will return UserInfo for the specified userId if exists or 
			// will throw exception if user with this userId does not exists
			//Syntax: public UserInfo getUserById(String userId,String orgId,
			//                                      UserInfo userInfo)
			UserInfo userInfo = sMgr.getUserById(userId, orgId, requestorUserInfo);
			
			
			
			// This method will grant specified role to the specified user if both role and user exists keeping previous roles in-tact. 
			// Otherwise, it will throw ISecurityException either if the user or role does not exists
			// Syntax : public void grantRoleToUser(UserInfo targetUInfo, RoleInfo rInfo, UserInfo userInfo)
			// @param targetUInfo : com.intellica.client.common.UserInfo class object to which roles has to be assigned.
			// @param rInfo - : com.intellica.client.security.RoleInfo object to be granted.
			// @param userInfo - : The details of the requesting user. 
			sMgr.grantRoleToUser(userInfo, roleInfo, requestorUserInfo);
		}
		catch (InterfaceInitException iie)
		{
            Logger.error("Could not connect to report server::" + iie.ErrorMessage);
		}
		catch (ISecurityException ie)
		{
			// Rootcause of the SecurityException sent by the report server
            Logger.error("Error from Server:" + ie.ExtMessage);
		}
		catch (System.Exception e)
		{
			Logger.error(e);
		}
	} // End of main function
}