//This API is used to assign the System Privileges to the User. 
//The user would require to provide its identity i.e. user Info as well as of the user 
//who is providing System Privileges.

//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll


/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>
using System;
using com.impetus.interaj.globals;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using UserInfo = com.intellica.client.common.UserInfo;
using ISecurityException = com.intellica.client.exception.ISecurityException;
// For exceptions during user management
using SecurityManager = com.intellica.client.security.SecurityManager;
// Has User management methods
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error
// in initializing the report Engine interface (REInterface). 

//This class assigns System Privileges to the user. User requires to provide its User ID so
// so to get the User instance and provide access rights to it.The required steps are :  
//1)get User Info object for the specified User Id
//2)Assign System privileges to the specified User,
public partial class UserManagement 
{
    public static void AssignSystemPrivilegesToUser()
	{
		try
		{
			
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String adminUserId = "Admin";
			System.String adminPassword = "Admin";
			System.String adminOrganization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(adminUserId, adminPassword, adminOrganization);
			
			// Create a SecurityManager class object 
			// for getting the controller information for all Administration related operations
			//public getInstance method to access the static instance of SecurityManager object
			//Syntax public static SecurityManager Instance
			SecurityManager sMgr = SecurityManager.Instance;
			
			// Provide the user ID of the User whose System Privileges are to be set 			
			System.String userId = "user5";
			System.String OrgId = "Org1";
			
			// This will return UserInfo for the specified userId if exists or 
			// will throw exception if user with this userId does not exists
			//Syntax: public UserInfo getUserById(String userId,String orgId,
			//        UserInfo userInfo)
			
			UserInfo userInfo = sMgr.getUserById(userId, OrgId, requestorUserInfo);
			
			
			//This method is used to set the System Privileges in the comma seperated format. 
			//Syntax : public void setSystemPrivileges(String systemPrivileges)
			userInfo.SystemPrivileges = com.intellica.client.utils.Utility.getRightsFromMaskedValue(com.intellica.client.common.Enums.SecurityTypes.SystemPrivileges.CATEGORY_SETUP | com.intellica.client.common.Enums.SecurityTypes.SystemPrivileges.SCHEDULER | com.intellica.client.common.Enums.SecurityTypes.SystemPrivileges.REPORT_DESIGNER);
			
			
			//Modifying the Access Rights of the User 
			//public void modifyUser(UserInfo targetUInfo,UserInfo userInfo)
			//@param targetUInfo - The UserInfo object containing the changed details of user 
			//@param userInfo - The current user details who is providing access rights 
			//					to the specified user.
			sMgr.modifyUser(userInfo, requestorUserInfo);
		}
		catch (InterfaceInitException iie)
		{
            Logger.error("Could not connect to report server::" + iie.ErrorMessage);
		}
		catch (ISecurityException ise)
		{
            Logger.error("Failed to Add user::");
		}
		catch (System.Exception e)
		{
			Logger.error(e);
		}
	} // End of main program
}