// This API is used to set the default User Preferences by the User.
//User would require to use following Intellicus dll files for using Intellicus APIs:
//1) Intellicus.core.dll
//2) log4net.dll
//3) Intellicus.XercesUtilities.dll


/// <summary> 
/// DISCLAIMER OF WARRANTY
/// This source code is provided "as is" and without warranties as to performance or merchantability. 
/// This source code is provided without any express or implied warranties whatsoever
/// </summary>
using System;
using com.impetus.interaj.globals;
using InteraConstants = com.intellica.client.common.InteraConstants;
using ReportClient = com.intellica.client.init.ReportClient;
// Has Init Method
using UserInfo = com.intellica.client.common.UserInfo;
using InterfaceInitException = com.intellica.client.exception.InterfaceInitException;
//Thrown as and when there is any error
// in initializing the report Engine interface (REInterface).
using PersonalizationHandlerException = com.intellica.client.exception.PersonalizationHandlerException;
using PersonalizationManager = com.intellica.client.personalization.PersonalizationManager;
//This class used for User Prefernces and 
//Dashboard related settings. It acts as the
//manager for all the classes in this package.
using Preferences = com.intellica.client.personalization.Preferences;
//Class contains the preferences of the user

/*
* This class is used to set the default User Preferences by the User.
*/
public partial class UserPreferences  
{
	
    public static void SetUserPreferences()
	{
		try
		{
			// Static Init call. it will read the properties for report server related attributes 
			// like server IP/Port and to create the logs at some desired location, set the absolute or the relative path where to create the logs 
			//in the INTERA_HOME property of the ReportClient.properties file.
            System.IO.Stream is_Renamed = new System.IO.FileStream("<path of ReportClient.Properties file>", System.IO.FileMode.Open, System.IO.FileAccess.Read);
			//with the absolute path of ReportClient.properties.
			ReportClient.init(is_Renamed);
			
			
			// Prepare a requestor user info bean object.
			// This user should be present in Intellicus application.
			//Syntax public UserInfo(String userId,String password,String orgId)constructor for creating UserInfo instance 
			//@param userId   - : Id of the User Logged-In.
			//@param password - : Password of the User Logged-In.
			//@param orgId    - : Organization Id from which User Logged-In.
			System.String adminUserId = "Admin";
			System.String adminPassword = "Admin";
			System.String adminOrganization = "Intellica";
			UserInfo requestorUserInfo = new UserInfo(adminUserId, adminPassword, adminOrganization);
			
			// This class used for User Prefernces and Dashboard related settings. It acts as the manager for all the classes in this package.
			// Overloaded constructor takes the report server address, TCP Socket number(port)
			PersonalizationManager pmanager = new PersonalizationManager();
			
			//Class contains the preferences of the user. The user preferences include 
			//Preferred Language of the user. 
			//Default Theme of the user. 
			//Default deleivery location for the reports of the user. 
			//Default report format for the user. 
			//Default email address of the user. 
			//Whether to show recent reports for the user. 
			//Whether to show reports published by the user. 
			//Whether to show the inbox to user. 
			//Default stylesheet of the user. 
			Preferences pref = new Preferences();
			pref = pmanager.getUserPreferences(requestorUserInfo);
			pref.ReportCount = 12;
			pref.TemplateName = "Beach";
			pref.ShowRecentReports = true;
			pref.DefaultConnection = "DemoReportDB";
			pref.DefaultPortalTheme = "Default";
			pref.Email = "hostUser@hostOrg.com";
			pref.Format = InteraConstants.ReportFormats.PDF;
			pref.PrefLanguage = "EN_US";
			//Set the working folder in userpreferences.
            pref.WorkingFolder = "6D564906-18CE-43FB-930C-DFB2D44792B3";
			
			//Method used to update the user preferences to the repository
			pmanager.updateUserPreferences(pref, requestorUserInfo);
		}
		catch (InterfaceInitException iie)
		{
            Logger.error("Could not connect to report server::" + iie.ErrorMessage);
		}
		catch (PersonalizationHandlerException phe)
		{
            Logger.error("Error Message:" + phe.ExtMessage);
		}
		catch (System.Exception e)
		{
			Logger.error(e);
		}
	}
}